PyTle
=====

.. currentmodule:: cysgp4

.. autoclass:: PyTle
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~PyTle.tle_strings

   .. rubric:: Methods Documentation

   .. automethod:: tle_strings
